@@ -5,10 +5,13 @@ from pydantic import BaseSettings
 # 其他地方出现的类似 from .. import config，均是从 __init__.py 导入的 Config 实例
 class Config(BaseSettings):
 
+    fastapi_reload: bool = False
     haruka_dir: Optional[str] = None
     haruka_to_me: bool = True
-    haruka_delete_pyppeteer: bool = False
     haruka_live_off_notify: bool = False
+    haruka_proxy: Optional[str] = None
+    haruka_interval: int = 10
+    haruka_dynamic_at: bool = False
 
     class Config:
         extra = "ignore"
