@@ -2,30 +2,31 @@ import asyncio
 import traceback
 from datetime import datetime, timedelta
 
+from bilireq.dynamic import get_user_dynamics
 from nonebot.log import logger
 
-from bilireq.dynamic import get_user_dynamics
-from ...database import DB
+from ... import config
+from ...database import DB as db
 from ...libs.dynamic import Dynamic
-from ...utils import safe_send, scheduler, get_dynamic_screenshot
+from ...utils import PROXIES, get_dynamic_screenshot, safe_send, scheduler
 
 last_time = {}
 
 
-@scheduler.scheduled_job("interval", seconds=10, id="dynamic_sched")
+@scheduler.scheduled_job("interval", seconds=config.haruka_interval, id="dynamic_sched")
 async def dy_sched():
     """直播推送"""
 
-    async with DB() as db:
-        uid = await db.next_uid("dynamic")
-        if not uid:
-            return
-        user = await db.get_user(uid)
-        assert user is not None
-        name = user.name
+    uid = await db.next_uid("dynamic")
+    if not uid:
+        return
+    user = await db.get_user(uid=uid)
+    assert user is not None
+    name = user.name
 
     logger.debug(f"爬取动态 {name}（{uid}）")
-    dynamics = (await get_user_dynamics(uid)).get("cards", [])  # 获取最近十二条动态
+    # 获取最近十二条动态
+    dynamics = (await get_user_dynamics(uid, proxies=PROXIES)).get("cards", [])
     # config['uid'][uid]['name'] = dynamics[0]['desc']['user_profile']['info']['uname']
     # await update_config(config)
 
@@ -37,7 +38,8 @@ async def dy_sched():
         last_time[uid] = dynamic.time
         return
 
-    for dynamic in dynamics[4::-1]:  # 从旧到新取最近5条动态
+    dynamic = None
+    for dynamic in dynamics[::-1]:  # 从旧到新取最近5条动态
         dynamic = Dynamic(**dynamic)
         if (
             dynamic.time > last_time[uid]
@@ -58,12 +60,17 @@ async def dy_sched():
                 logger.error("已达到重试上限，将在下个轮询中重新尝试")
             await dynamic.format(image)
 
-            async with DB() as db:
-                push_list = await db.get_push_list(uid, "dynamic")
-                for sets in push_list:
-                    await safe_send(
-                        sets.bot_id, sets.type, sets.type_id, dynamic.message
-                    )
+            push_list = await db.get_push_list(uid, "dynamic")
+            for sets in push_list:
+                await safe_send(
+                    bot_id=sets.bot_id,
+                    send_type=sets.type,
+                    type_id=sets.type_id,
+                    message=dynamic.message,
+                    at=bool(sets.at) and config.haruka_dynamic_at,
+                )
 
             last_time[uid] = dynamic.time
-    await DB.update_user(uid, dynamic.name)  # type: ignore
+
+    if dynamic:
+        await db.update_user(uid, dynamic.name)
